function x_mz=mz_hdf5tosci(file_in,max_scans)
    
    // entrees: -------------------------
    // file_in: un fichier au format HDF5 
    // max_scans: valeur introduite pour accelerer la fonction de test
    
    // sorties: ---------------------------
    // x_mz: une variable avec deux champs:
    // x_mz.time
    // x_mz.mzdata une liste dont chaque élément est un vecteur de 2 colonnes: m/z et intensités de signal
    
    // JCB 2 aout18
    
    
    
    // lecture du fichier HDF5 ----------------------------------
    a=h5open(file_in,'a');
    spectrum_chromatogram_index=h5read(a.root.ChromatogramIndex);
    spectrum_time=h5read(a.root.ChomatogramTime);
    spectrum_intensity=h5read(a.root.SpectrumIntensity);
    spectrum_mz=h5read(a.root.SpectrumMZ);
    spectrum_index=h5read(a.root.SpectrumIndex);
    h5close(a)
    
    // reconstruction du spectre -----------------
    if argn(2)==1 then
        nbr_scans=double(spectrum_chromatogram_index);
    else
        nbr_scans=max_scans;
    end
 
    // 1- extraction du temps 
    time=spectrum_time(1:nbr_scans);
    mzdata=list();
    
    //disp(nbr_scans,'nbr_scans=')
    
    for i=1:nbr_scans;
        if i==1 then 
            plage_i=[1,double(spectrum_index(i))];
        else 
            plage_i=[double(spectrum_index(i-1))+1,double(spectrum_index(i))];
        end
        
        // 2- extraction et reconstruction des m/z
        // dans le fichier HDF5, ne sont enregistrées que les différences de m/z entre 2 mesures
        mz_i=spectrum_mz(plage_i(1):plage_i(2));
        
        n=size(mz_i,2);
        mz_i2=zeros(1,n);
        
        mz_i2(1)=mz_i(1);
        for j=2:n;
            mz_i2(j)=mz_i2(j-1)+mz_i(j);
        end
        
        // 3- extraction des signaux
        sig_i=spectrum_intensity(plage_i(1):plage_i(2));

        // regroupement des m/z et signaux
        sp_i=[mz_i2;sig_i];
        
        mzdata(i)=sp_i';
        
        // disp(i,'i=')
        
    end
    
    x_mz.time=time;
    x_mz.mzdata=mzdata;
    
    
endfunction
